/**
 * jQuery Window Popup
 * 
 * Description: Window popup for remote url
 * Version: 1.0.0
 * URL: https://github.com/krescentmoon/jquery-window-popup
 * Author: Krescentmoon
 * License: MIT License
 */

// the semi-colon before the function invocation is a safety net against concatenated 
// scripts and/or other plugins that are not closed properly
;(function ( $, window, document, undefined ) {

    $.fn.extend({
        winpopup: function( options ) {

            // the added first parameter of TRUE to signify a DEEP COPY:
            var settings = $.extend( true, {}, {
                url         : 'https://google.com',
                name        : 'jquery window popup', // '_blank', '_parent', '_self', '_top', 'name'
                width       : 640, // pixel | The minimum required value is 100
                height      : 640, // pixel | The minimum required value is 100
                top         : 0,   // pixel
                left        : 0,   // pixel
                status      : 0,   // yes, no, 1, 0
                menubar     : 0,   // yes, no, 1, 0
                location    : 0,   // yes, no, 1, 0 | Opera only
                toolbar     : 0,   // yes, no, 1, 0 | IE, Firefox only
                scrollbars  : 0,   // yes, no, 1, 0 | IE, Firefox & Opera only
                resizable   : 0,   // yes, no, 1, 0 | IE only
                channelmode : 0,   // yes, no, 1, 0 | IE only
                fullscreen  : 0,   // yes, no, 1, 0 | IE only
                titlebar    : 1,   // yes, no, 1, 0 | Ignored unless the calling application is an HTML Application or a trusted dialog box
                alignment   : 'middle-center' // 'top-left', 'top-center', 'top-right', 'middle-left', 'middle-center', 'middle-right', 'bottom-left', 'bottom-center', 'bottom-right'
            }, options );

            return this.each(function() {
                initialize(this,settings);
            });

        }
    });

    function initialize(element,settings) {

        if ( ! $(element).length ) {
            return;
        }

        var $element = $(element);

        // Merging data-attribute and settings
        var opts = $.extend( true, {}, settings, $element.data('winpopup') );
            opts.url = ( $element.attr('href') !== undefined ) ? $element.attr('href') : opts.url;
            opts.name = ( $element.attr('title') !== undefined ) ? $element.attr('title') : opts.name;

        // remove whitespace in name
        opts.name = $.trim(opts.name);

        // alignment
        switch( opts.alignment ) {
            case 'top-left':
                opts.top  = Math.round( 0 + opts.top );
                opts.left = Math.round( 0 + opts.left );
                break;
            case 'top-center':
                opts.top  = Math.round( 0 + opts.top );
                opts.left = Math.round( window.screen.width / 2 - opts.width / 2 + opts.left );
                break;
            case 'top-right':
                opts.top  = Math.round( 0 + opts.top );
                opts.left = Math.round( window.screen.width - opts.width + opts.left);
                break;
            case 'middle-left':
                opts.top  = Math.round( window.screen.height / 2 - opts.height / 2 + opts.top );
                opts.left = Math.round( 0 + opts.left );
                break;
            case 'middle-center':
                opts.top  = Math.round( window.screen.height / 2 - opts.height / 2 + opts.top );
                opts.left = Math.round( window.screen.width / 2 - opts.width / 2 + opts.left );
                break;
            case 'middle-right':
                opts.top  = Math.round( window.screen.height / 2 - opts.height / 2 + opts.top );
                opts.left = Math.round( window.screen.width - opts.width + opts.left);
                break;
            case 'bottom-left':
                opts.top = Math.round( window.screen.height - opts.height + opts.top);
                opts.left = Math.round( 0 + opts.left );
                break;
            case 'bottom-center':
                opts.top = Math.round( window.screen.height - opts.height + opts.top);
                opts.left = Math.round( window.screen.width / 2 - opts.width / 2 + opts.left );
                break;
            case 'bottom-right':
                opts.top = Math.round( window.screen.height - opts.height + opts.top);
                opts.left = Math.round( window.screen.width - opts.width + opts.left);
                break;
        }

        // feature
        var feature  = '';
            feature += 'width='+ opts.width +',';
            feature += 'height='+ opts.height +',';
            feature += 'top='+ opts.top +',';
            feature += 'left='+ opts.left +',';
            feature += 'status='+ opts.status +',';
            feature += 'menubar='+ opts.menubar +',';
            feature += 'location='+ opts.location +',';
            feature += 'toolbar='+ opts.toolbar +',';
            feature += 'scrollbars='+ opts.scrollbars +',';
            feature += 'resizable='+ opts.resizable +',';
            feature += 'channelmode='+ opts.channelmode +',';
            feature += 'fullscreen='+ opts.fullscreen +',';
            feature += 'titlebar='+ opts.titlebar;

        // click
        $element.on( 'click', function(event){
            // 'event' is null or not an object
            event = event || window.event;
            event.preventDefault();
            // window open
            var w = window.open( opts.url, opts.name, feature );
            w.onload = function(){
                setTimeout(function(){
                    w.document.title = opts.name;
                    w.focus();
                }, 1000);
            };
            return false;
        });
    }

})( jQuery, window, document );